#include <Wire.h>
#include "Definitions.h"
#include "pins_arduino.h"

#define IRpin 2                              // this must be an external interrupt pin for the IR receiver
#define ComMotion 30                         // I²C address of ComMotion shield with all dipswitches in the "off" position

void pulse(int pin, int times);
int error=0;
int pmode=0;
byte datapack[32];                           // I²C buffer is 32 bytes
volatile byte IRC;                           // global variable used to store IR Command
int velocity=0,angle=0,rotation=0;

void setup() 
{
  Serial.begin(19200);                       // set baud rate to suit ISP programmer
  attachInterrupt(0,IRdecode,CHANGE);        // call IRdecode when IRpin changes state (use external interrupt that matches IRpin)
  Wire.begin();                              // Join I²C bus as master
    
   
  pinMode(2,INPUT);                          // D2 connects to IR receiver pin 1 (signal)
  pinMode(3,OUTPUT);                         // D3 connects to IR receiver pin 2 (ground)
  pinMode(4,OUTPUT);                         // D4 connects to IR receiver pin 3 (supply)
  
  digitalWrite(2,1);                         // enable pullup resistor on D2
  digitalWrite(3,0);                         // set D3 to ground
  digitalWrite(4,1);                         // set D4 to +5V
  
  // Rover5Mecanum();                        // enable this line for Rover 5 with mecanum wheels
  // ScamperDemo();                          // enable this line for Scamper kit demo mode
  // ScamperI2C();                           // enable this line for Scamper kit I²C control
}

void loop() 
{
  //------------------------------------------- Upload New Code Via ISP -----------------------------
  if (Serial.available()) 
  {
    avrisp();
  }
  
  //------------------------------------------- Respond To IR Command -------------------------------
  if(IRC!=0)                                 // has an IR command been received?                                               
  {
    Serial.println(IRC,DEC);
    if(IRC==1) angle=315;                    //   ---+---+---
    if(IRC==2) angle=0;                      //  | 1 | 2 | 3 |
    if(IRC==3) angle=45;                     //   ---+---+---
    if(IRC==4) angle=270;                    //  | 4 | 5 | 6 |
    if(IRC==6) angle=90;                     //   ---+---+---
    if(IRC==7) angle=225;                    //  | 7 | 8 | 9 |
    if(IRC==8) angle=180;                    //   ---+---+---
    if(IRC==9) angle=135;
    
    if(IRC==17) velocity+=5;                 //       17
    if(IRC==18) velocity-=5;                 //    19 38 20
    if(IRC==19) rotation-=5;                 //       18
    if(IRC==20) rotation+=5;
    
    if(IRC==38 || IRC==5)                    // 5 or 38 equals stop!
    {
      velocity=0;
      angle=0;
      rotation=0;
    }
    
    if(velocity>255) velocity=255;
    if(velocity<-255) velocity=-255;
    if(rotation>255) rotation=255;
    if(rotation<-255) rotation=-255;
    if(angle>=360) angle=angle-360;
    if(angle<0) angle+=360;
    
    Wire.beginTransmission(ComMotion);       // start transmission to ComMotion shield
    Wire.write(3);                           // command 3 -- Motor Control 
    Wire.write(highByte(velocity));          // send high byte of velocity integer
    Wire.write( lowByte(velocity));          // send  low byte of velocity integer
    Wire.write(highByte(angle));             // send high byte of angle integer
    Wire.write( lowByte(angle));             // send  low byte of angle integer
    Wire.write(highByte(rotation));          // send high byte of rotation integer
    Wire.write( lowByte(rotation));          // send  low byte of rotation integer
    Wire.endTransmission();                  // complete transmission of data
    
    delay(50);                               // delay 50mS helps prevent unwanted command repeats
    IRC=0;                                   // reset IRC to prevent commands repeating
  }
}

